@@ -1,12 +1,12 @@
 from .utils import filter
-from typing import Optional
 from .video import Video
 from .channel import Channel
 from .playlist import Playlist
-from .videobulk import VideoBulk
-from .channelbulk import ChannelBulk
-from .playlistbulk import PlaylistBulk
+from .videobulk import _VideoBulk
+from .channelbulk import _ChannelBulk
+from .playlistbulk import _PlaylistBulk
 from ._rgxs import _QueryPatterns as rgx
+from typing import Optional, Optional, Dict, Any
 from ._http import _find_videos, _find_channels, _find_playlists
 
 
@@ -29,19 +29,19 @@ class Search:
         return Playlist(found[0]) if found else None
 
     @staticmethod
-    def videos(keywords: str, limit: int = 20) -> Optional[VideoBulk]:
+    def videos(keywords: str, limit: int = 20) -> Optional[Dict[str, Dict[str, Any]]]:
         video_ids = rgx.video_id.findall(_find_videos(keywords))
         pure_list = filter(limit=limit, iterable=video_ids)
-        return VideoBulk(pure_list) if pure_list else None
+        return _VideoBulk(pure_list)._gen_bulk() if pure_list else None
 
     @staticmethod
-    def channels(keywords: str, limit: int = 20) -> Optional[ChannelBulk]:
+    def channels(keywords: str, limit: int = 20) -> Optional[Dict[str, Dict[str, Any]]]:
         channel_ids = rgx.channel_id.findall(_find_channels(keywords))
         pure_list = filter(limit=limit, iterable=channel_ids)
-        return ChannelBulk(pure_list) if pure_list else None
+        return _ChannelBulk(pure_list)._gen_bulk() if pure_list else None
 
     @staticmethod
-    def playlists(keywords: str, limit: int = 20) -> Optional[PlaylistBulk]:
+    def playlists(keywords: str, limit: int = 20) -> Optional[Dict[str, Dict[str, Any]]]:
         playlist_ids = rgx.playlist_id.findall(_find_playlists(keywords))
         pure_list = filter(limit=limit, iterable=playlist_ids)
-        return PlaylistBulk(pure_list) if pure_list else None
+        return _PlaylistBulk(pure_list)._gen_bulk() if pure_list else None
